/* Created by Ville-Petteri Makinen
   email: vpmakine@gmail.com */

#include "punos.h"

using namespace std;

/*
 *
 */
string
punos::version() {
  return ("427.numero.20210105");
}
